#!/bin/bash

# Define variables
MOUNT_POINT="/mnt/ramdisk"
SIZE="1G"  # You can adjust this size (e.g., 512M, 2G)

# Function to create and mount tmpfs RAM disk
create_ramdisk() {
    if [ ! -d "$MOUNT_POINT" ]; then
        echo "Creating mount point at $MOUNT_POINT..."
        sudo mkdir -p "$MOUNT_POINT"
    fi

    echo "Mounting tmpfs at $MOUNT_POINT with size $SIZE..."
    sudo mount -t tmpfs -o size=$SIZE tmpfs $MOUNT_POINT

    echo "RAM disk mounted at $MOUNT_POINT with size $SIZE"
}

# Function to check the RAM disk
check_ramdisk() {
    echo "Checking mounted RAM disks..."
    df -h | grep "$MOUNT_POINT"
}

# Function to unmount and clean up the RAM disk
unmount_ramdisk() {
    echo "Unmounting RAM disk at $MOUNT_POINT..."
    sudo umount $MOUNT_POINT

    if [ $? -eq 0 ]; then
        echo "Successfully unmounted $MOUNT_POINT"
    else
        echo "Failed to unmount $MOUNT_POINT"
    fi
}

# Main menu
echo "Choose an option:"
echo "1. Create and mount RAM disk"
echo "2. Check RAM disk"
echo "3. Unmount RAM disk"
echo "4. Exit"

read -p "Enter your choice [1-4]: " choice

case $choice in
    1)
        create_ramdisk
        ;;
    2)
        check_ramdisk
        ;;
    3)
        unmount_ramdisk
        ;;
    4)
        echo "Exiting."
        ;;
    *)
        echo "Invalid option!"
        ;;
esac
